@@ -1,15 +1,22 @@
+import os
 import pathlib
 
 import numpy as np
 
+import pytest
+
 import radontea
 import sinogram
 
 
+# See https://github.com/RI-imaging/radontea/issues/6
+CI_FAILS = (os.environ.get("RUNNER_OS", "None") == "Linux")
+
+
+@pytest.mark.xfail(CI_FAILS, reason="Unexplained issue #6")
 def test_2d_art():
     sino, angles = sinogram.create_test_sino(A=100, N=100)
     r = radontea.art(sino, angles)
-
     # np.savetxt('outfile.txt', np.array(r).flatten().view(float), fmt="%.8f")
     reffile = pathlib.Path(__file__).parent / "data" / "2d_art.txt"
     ref = np.loadtxt(str(reffile))
