@@ -1,15 +1,21 @@
+import os
 import pathlib
-import sys
 
 import numpy as np
+
 import pytest
+
 import radontea
 
 import sinogram
 
+# See https://github.com/RI-imaging/radontea/issues/6
+CI_FAILS = (os.environ.get("RUNNER_OS", "None") == "Linux"
+            or os.environ.get("RUNNER_OS", "None") == "macOS"
+            or os.environ.get("RUNNER_OS", "None") == "Windows")
 
-# fails on Windows and macOS
-@pytest.mark.xfail(sys.platform != "linux", reason="don't know why")
+
+@pytest.mark.xfail(CI_FAILS, reason="Unexplained issue #6")
 def test_2d_fmp():
     sino, angles = sinogram.create_test_sino(A=100, N=101)
     r = radontea.fourier_map(sino, angles)
