@@ -1,12 +1,20 @@
+import os
 import pathlib
 
 import numpy as np
 
+import pytest
+
 import radontea
 
 import sinogram
 
 
+# See https://github.com/RI-imaging/radontea/issues/6
+CI_FAILS = (os.environ.get("RUNNER_OS", "None") == "Linux")
+
+
+@pytest.mark.xfail(CI_FAILS, reason="Unexplained issue #6")
 def test_2d_sart():
     sino, angles = sinogram.create_test_sino(A=100, N=100)
     r = radontea.sart(sino, angles)
